@@ -102,7 +102,11 @@ module MiniMagick
       end
       ext.sub!(/:.*/, '') # hack for filenames or URLs that include a colon
 
-      openable.open(options) { |file| read(file, ext) }
+      if openable.is_a?(URI::Generic)
+        openable.open(options) { |file| read(file, ext) }
+      else
+        openable.open(**options) { |file| read(file, ext) }
+      end
     end
 
     ##
@@ -583,5 +587,31 @@ module MiniMagick
     def layer?
       path =~ /\[\d+\]$/
     end
+
+    ##
+    # Compares if image width
+    # is greater than height
+    # ============
+    # |          |
+    # |          |
+    # ============
+    # @return [Boolean]
+    def landscape?
+      width > height
+    end
+
+    ##
+    # Compares if image height
+    # is greater than width
+    # ======
+    # |    |
+    # |    |
+    # |    |
+    # |    |
+    # ======
+    # @return [Boolean]
+    def portrait?
+      height > width
+    end
   end
 end
