@@ -47,18 +47,21 @@ RSpec.describe MiniMagick::Configuration do
   end
 
   describe "#processor" do
-    it "assigns 'mogrify' if ImageMagick 6 is available" do
+    it "assigns 'mogrify' if ImageMagick 6 is available, and others are not" do
+      allow(MiniMagick::Utilities).to receive(:which).with("magick").and_return(nil)
+      allow(MiniMagick::Utilities).to receive(:which).with("gm").and_return(nil)
       allow(MiniMagick::Utilities).to receive(:which).with("mogrify").and_return(true)
       expect(subject.processor).to eq "mogrify"
     end
 
-    it "assigns 'gm' if ImageMagick 6 is not available" do
-      allow(MiniMagick::Utilities).to receive(:which).with("mogrify").and_return(nil)
+    it "assigns 'gm' if others are not available" do
+      allow(MiniMagick::Utilities).to receive(:which).with("magick").and_return(nil)
       allow(MiniMagick::Utilities).to receive(:which).with("gm").and_return(true)
+      allow(MiniMagick::Utilities).to receive(:which).with("mogrify").and_return(nil)
       expect(subject.processor).to eq "gm"
     end
 
-    it "assigns 'magick' if ImageMagick 6 and GraphicsMagick are not available" do
+    it "assigns 'magick' if ImageMagick 7 available" do
       allow(MiniMagick::Utilities).to receive(:which).with("mogrify").and_return(nil)
       allow(MiniMagick::Utilities).to receive(:which).with("gm").and_return(nil)
       allow(MiniMagick::Utilities).to receive(:which).with("magick").and_return(true)
@@ -66,9 +69,9 @@ RSpec.describe MiniMagick::Configuration do
     end
 
     it "returns nil if neither ImageMagick nor GraphicsMagick are available" do
-      allow(MiniMagick::Utilities).to receive(:which).with("mogrify").and_return(nil)
-      allow(MiniMagick::Utilities).to receive(:which).with("gm").and_return(nil)
       allow(MiniMagick::Utilities).to receive(:which).with("magick").and_return(nil)
+      allow(MiniMagick::Utilities).to receive(:which).with("gm").and_return(nil)
+      allow(MiniMagick::Utilities).to receive(:which).with("mogrify").and_return(nil)
       expect(subject.processor).to eq nil
     end
   end
